package com.ruoyi.hezhi.service;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.hezhi.domain.TbMemberJoin;
import com.ruoyi.hezhi.domain.dto.MemberJoinDTO;

import java.util.List;

/**
 * 用户参与Service接口
 *
 * @author ruoyi
 * @date 2024-11-15
 */
public interface ITbMemberJoinService
{
    /**
     * 查询用户参与
     *
     * @param memberJoinId 用户参与主键
     * @return 用户参与
     */
    public TbMemberJoin selectTbMemberJoinByMemberJoinId(Long memberJoinId);

    /**
     * 查询用户参与列表
     *
     * @param tbMemberJoin 用户参与
     * @return 用户参与集合
     */
    public List<TbMemberJoin> selectTbMemberJoinList(TbMemberJoin tbMemberJoin);

    /**
     * 新增用户参与
     *
     * @param tbMemberJoin 用户参与
     * @return 结果
     */
    public int insertTbMemberJoin(TbMemberJoin tbMemberJoin);

    /**
     * 修改用户参与
     *
     * @param tbMemberJoin 用户参与
     * @return 结果
     */
    public int updateTbMemberJoin(TbMemberJoin tbMemberJoin);

    /**
     * 批量删除用户参与
     *
     * @param memberJoinIds 需要删除的用户参与主键集合
     * @return 结果
     */
    public int deleteTbMemberJoinByMemberJoinIds(Long[] memberJoinIds);

    /**
     * 删除用户参与信息
     *
     * @param memberJoinId 用户参与主键
     * @return 结果
     */
    public int deleteTbMemberJoinByMemberJoinId(Long memberJoinId);

    /**
     * 立即参加
     *
     * @param memberJoinDTO
     * @return ok
     */
    public AjaxResult joinNow(MemberJoinDTO memberJoinDTO);
}
